/*
This file is part of libmsppath
Copyright © 2006  Mikko Rasa, Mikkosoft Productions
Distributed under the LGPL
*/
#ifndef MSP_PATH_PATH_H_
#define MSP_PATH_PATH_H_

#include <ostream>
#include <string>

namespace Msp {
namespace Path {

enum
{
#ifdef WIN32
	DIRCHAR='\\'
#else
	DIRCHAR='/'
#endif
};

class Path
{
public:
	class iterator
	{
	public:
		iterator    &operator++();
		iterator    &operator--();
		std::string operator*() const;
		bool        operator==(const iterator &i) const { return (start==i.start && end==i.end); }
		bool        operator!=(const iterator &i) const { return !(*this==i); }
	private:
		const Path &path;
		unsigned   start,end;

		iterator(const Path &);

		friend class Path;
	};

	Path() { }
	Path(const std::string &p)     { init(p); }
	Path(const char *p)            { init(p); }
	const std::string &str() const { return path; }
	unsigned    size() const;
	bool        empty() const { return path.empty(); }
	bool        is_absolute() const;
	Path        subpath(unsigned, unsigned =(unsigned)-1) const;
	Path        operator/(const Path &p) const { Path a=*this; a/=p; return a; }
	Path        &operator/=(const Path &);
	std::string operator[](int) const;
	bool        operator==(const Path &) const;
	iterator    begin() const { return iterator(*this); }
	iterator    end() const   { iterator i(*this); i.start=i.end=std::string::npos; return i; }
private:
	std::string path;

	void init(const std::string &);
	void add_component(const std::string &);
};

inline std::ostream &operator<<(std::ostream &o, const Path &p) { o<<p.str(); return o; }

} // namespace Path
} // namespace Msp

#endif
